pub enum ApolloRouterError {
StartupError,
HttpServerLifecycleError,
NoConfiguration,
NoSchema,
NoLicense,
LicenseViolation(Vec<String>),
ServiceCreationError(BoxError),
ServerCreationError(Error),
DifferentListenAddrsOnSamePort(IpAddr, IpAddr, u16),
SameRouteUsedTwice(IpAddr, u16, String),
Rustls(Error),
FeatureGateViolation,
}Expand description
Error types for FederatedServer.
Variants
StartupError
failed to start server
HttpServerLifecycleError
failed to stop HTTP Server
NoConfiguration
no valid configuration was supplied
NoSchema
no valid schema was supplied
NoLicense
no valid license was supplied
LicenseViolation(Vec<String>)
license violation, the router is using features not available for your license: {0:?}
ServiceCreationError(BoxError)
could not create router: {0}
ServerCreationError(Error)
could not create the HTTP server: {0}
DifferentListenAddrsOnSamePort(IpAddr, IpAddr, u16)
tried to bind {0} and {1} on port {2}
SameRouteUsedTwice(IpAddr, u16, String)
tried to register two endpoints on {0}:{1}{2}
Rustls(Error)
TLS configuration error: {0}
FeatureGateViolation
Preview feature in supergraph schema not enabled via configuration