#[non_exhaustive]pub enum ConfigurationSource {
Static(Box<Configuration>),
Stream(Pin<Box<dyn Stream<Item = Configuration> + Send>>),
File {
path: PathBuf,
watch: bool,
},
}Expand description
The user supplied config. Either a static instance or a stream for hot reloading.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Static(Box<Configuration>)
A static configuration.
Can be created through serde::Deserialize from various formats,
or inline in Rust code with serde_json::json! and serde_json::from_value.
Stream(Pin<Box<dyn Stream<Item = Configuration> + Send>>)
A configuration stream where the server will react to new configuration. If possible the configuration will be applied without restarting the internal http server.
File
A yaml file that may be watched for changes