#[non_exhaustive]pub enum LicenseSource {
Static {
license: License,
},
Env,
Stream(Pin<Box<dyn Stream<Item = License> + Send>>),
File {
path: PathBuf,
watch: bool,
},
Registry(UplinkConfig),
}Expand description
License controls availability of certain features of the Router. This API experimental and is subject to change outside of semver.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Static
A static license. EXPERIMENTAL and not subject to semver.
Fields
license: LicenseEnv
A license supplied via APOLLO_ROUTER_LICENSE. EXPERIMENTAL and not subject to semver.
Stream(Pin<Box<dyn Stream<Item = License> + Send>>)
A stream of license. EXPERIMENTAL and not subject to semver.
File
A raw file that may be watched for changes. EXPERIMENTAL and not subject to semver.
Fields
Registry(UplinkConfig)
Apollo uplink.