pub enum JsonPathElement {
Flatten(Option<Vec<String>>),
Index(usize),
Fragment(String),
Key(String, Option<Vec<String>>),
}Expand description
A GraphQL path element that is composes of strings or numbers.
e.g /book/3/name
Variants
Flatten(Option<Vec<String>>)
A path element that given an array will flatmap the content.
Index(usize)
An index path element.
Fragment(String)
A fragment application
Key(String, Option<Vec<String>>)
A key path element.