Error

Struct Error 

#[non_exhaustive]
pub struct Error { pub message: String, pub locations: Vec<Location>, pub path: Option<Path>, pub extensions: Map<ByteString, Value>, /* private fields */ }
A GraphQL error as may be found in the errors field of a GraphQL Response.

Converted to (or from) JSON with serde.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
message: String

The error message.

locations: Vec<Location>

The locations of the error in the GraphQL document of the originating request.

path: Option<Path>

If this is a field error, the JSON path to that field in Response::data

extensions: Map<ByteString, Value>

The optional GraphQL extensions for this error.

Implementations

Source

impl Error

pub fn extension_code(&self) -> Option<String>

Extract the error code from Error::extensions as a String if it is set.

pub fn apollo_id(&self) -> Uuid

Retrieve the internal Apollo unique ID for this error

pub fn with_apollo_id(&self, id: Uuid) -> Self

Returns a duplicate of the error where self.apollo_id is now the given ID

Source

impl Error

pub fn builder() -> NewErrorBuilder

Returns a builder that builds a GraphQL Error from its components.

Builder methods:

  • .message(impl Into<String>) Required. Sets Error::message.

  • .locations(impl Into<Vec<Location>>) Optional. Sets the entire Vec of Error::locations, which defaults to the empty.

  • .location(impl Into<Location>) Optional, may be called multiple times. Adds one item at the end of Error::locations.

  • .path(impl Into<Path>) Optional. Sets Error::path.

  • .extensions(impl Into<serde_json_bytes::Map<ByteString, Value>>) Optional. Sets the entire Error::extensions map, which defaults to empty.

  • .extension(impl Into<ByteString>, impl Into<Value>) Optional, may be called multiple times. Adds one item to the Error::extensions map.

  • .extension_code(impl Into<String>) Optional. Sets the “code” in the extension map. Will be ignored if extension already has this key set.

  • .apollo_id(impl Into<Uuid>) Optional. Sets the unique identifier for this Error. This should only be used in cases of deserialization or testing. If not given, the ID will be auto-generated.

  • .build() Finishes the builder and returns a GraphQL Error.