#[non_exhaustive]pub struct IncrementalResponse {
pub label: Option<String>,
pub data: Option<Value>,
pub path: Option<Path>,
pub errors: Vec<Error>,
pub extensions: Map<ByteString, Value>,
}Expand description
A graphql incremental response.
Used with @defer
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.label: Option<String>The label that was passed to the defer or stream directive for this patch.
data: Option<Value>The response data.
path: Option<Path>The path that the data should be merged at.
errors: Vec<Error>The optional graphql errors encountered.
extensions: Map<ByteString, Value>The optional graphql extensions.
Implementations
Sourceimpl IncrementalResponse
impl IncrementalResponse
Sourcepub fn append_errors(&mut self, errors: &mut Vec<Error>)
pub fn append_errors(&mut self, errors: &mut Vec<Error>)
append_errors default the errors path with the one provided.