#[non_exhaustive]pub struct Request {
pub query: Option<String>,
pub operation_name: Option<String>,
pub variables: Map<ByteString, Value>,
pub extensions: Map<ByteString, Value>,
}Expand description
A GraphQL Request used to represent both supergraph and subgraph requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query: Option<String>The GraphQL operation (e.g., query, mutation) string.
For historical purposes, the term “query” is commonly used to refer to
any GraphQL operation which might be, e.g., a mutation.
operation_name: Option<String>The (optional) GraphQL operation name.
When specified, this name must match the name of an operation in the
GraphQL document. When excluded, there must exist only a single
operation in the GraphQL document. Typically, this value is provided as
the operationName on an HTTP-sourced GraphQL request.
variables: Map<ByteString, Value>The (optional) GraphQL variables in the form of a JSON object.
When specified, these variables can be referred to in the query by
using $variableName syntax, where {"variableName": "value"} has been
specified as this variables value.
extensions: Map<ByteString, Value>The (optional) GraphQL extensions of a GraphQL request.
The implementations of extensions are server specific and not specified by
the GraphQL specification.
For example, Apollo projects support Automated Persisted Queries
which are specified in the extensions of a request by populating the
persistedQuery key within the extensions object:
{
"query": "...",
"variables": { /* ... */ },
"extensions": {
"persistedQuery": {
"version": 1,
"sha256Hash": "sha256HashOfQuery"
. }
}
}Note we allow null when deserializing as per graphql-over-http spec
Implementations
Sourceimpl Request
impl Request
Sourcepub fn deserialize_from_bytes(data: &Bytes) -> Result<Self, Error>
pub fn deserialize_from_bytes(data: &Bytes) -> Result<Self, Error>
Deserialize as JSON from &Bytes, avoiding string copies where possible
Sourcepub fn from_urlencoded_query(
url_encoded_query: String,
) -> Result<Request, Error>
pub fn from_urlencoded_query( url_encoded_query: String, ) -> Result<Request, Error>
Convert encoded URL query string parameters (also known as “search
params”) into a GraphQL Request.
An error will be produced in the event that the query string parameters
cannot be turned into a valid GraphQL Request.
Sourceimpl Request
impl Request
Sourcepub fn builder() -> __RequestBuilder<(__Optional<Option<String>>, __Optional<Option<String>>, __Optional<Map<ByteString, Value>>, __Optional<Map<ByteString, Value>>)>
pub fn builder() -> __RequestBuilder<(__Optional<Option<String>>, __Optional<Option<String>>, __Optional<Map<ByteString, Value>>, __Optional<Map<ByteString, Value>>)>
This is the constructor (or builder) to use when constructing a GraphQL
Request.
The optionality of parameters on this constructor match the runtime
requirements which are necessary to create a valid GraphQL Request.
(This contrasts against the fake_new constructor which may be more
tolerant to missing properties which are only necessary for testing
purposes. If you are writing tests, you may want to use Self::fake_new().)
Sourceimpl Request
impl Request
Sourcepub fn fake_builder() -> __RequestBuilder<(__Optional<Option<String>>, __Optional<Option<String>>, __Optional<Map<ByteString, Value>>, __Optional<Map<ByteString, Value>>)>
pub fn fake_builder() -> __RequestBuilder<(__Optional<Option<String>>, __Optional<Option<String>>, __Optional<Map<ByteString, Value>>, __Optional<Map<ByteString, Value>>)>
This is the constructor (or builder) to use when constructing a fake
GraphQL Request. Use Self::new() to construct a real request.
This is offered for testing purposes and it relaxes the requirements
of some parameters to be specified that would be otherwise required
for a real request. It’s usually enough for most testing purposes,
especially when a fully constructed Request is difficult to construct.
While today, its parameters have the same optionality as its new
counterpart, that may change in future versions.