#[non_exhaustive]pub struct Response {
pub label: Option<String>,
pub data: Option<Value>,
pub path: Option<Path>,
pub errors: Vec<Error>,
pub extensions: Map<ByteString, Value>,
pub has_next: Option<bool>,
pub subscribed: Option<bool>,
pub created_at: Option<Instant>,
pub incremental: Vec<IncrementalResponse>,
}Expand description
A graphql primary response. Used for federated and subgraph queries.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.label: Option<String>The label that was passed to the defer or stream directive for this patch.
data: Option<Value>The response data.
path: Option<Path>The path that the data should be merged at.
errors: Vec<Error>The optional graphql errors encountered.
extensions: Map<ByteString, Value>The optional graphql extensions.
has_next: Option<bool>subscribed: Option<bool>created_at: Option<Instant>Used for subscription event to compute the duration of a subscription event
incremental: Vec<IncrementalResponse>Implementations
Sourceimpl Response
impl Response
Sourcepub fn is_primary(&self) -> bool
pub fn is_primary(&self) -> bool
If path is None, this is a primary response.
Sourcepub fn append_errors(&mut self, errors: &mut Vec<Error>)
pub fn append_errors(&mut self, errors: &mut Vec<Error>)
append_errors default the errors path with the one provided.
Sourceimpl Response
impl Response
Sourcepub fn builder() -> __ResponseBuilder<(__Optional<Option<String>>, __Optional<Option<Value>>, __Optional<Option<Path>>, __Optional<Vec<Error>>, __Optional<Map<ByteString, Value>>, __Optional<Option<String>>, __Optional<Option<bool>>, __Optional<Option<bool>>, __Optional<Vec<IncrementalResponse>>, __Optional<Option<Instant>>)>
pub fn builder() -> __ResponseBuilder<(__Optional<Option<String>>, __Optional<Option<Value>>, __Optional<Option<Path>>, __Optional<Vec<Error>>, __Optional<Map<ByteString, Value>>, __Optional<Option<String>>, __Optional<Option<bool>>, __Optional<Option<bool>>, __Optional<Vec<IncrementalResponse>>, __Optional<Option<Instant>>)>
Constructor