UnconstrainedBufferLayer

Struct UnconstrainedBufferLayer 

pub struct UnconstrainedBufferLayer<Request> { /* private fields */ }
Adds a coop unconstrained Buffer layer to a service.

See the module documentation for more details.

Implementations

Source

impl<Request> UnconstrainedBufferLayer<Request>

pub const fn new(bound: usize) -> Self

Creates a new UnconstrainedBufferLayer with the provided bound.

bound gives the maximal number of requests that can be queued for the service before backpressure is applied to callers.

See Buffer::new for guidance on choosing a bound.