macro_rules! register_plugin {
($group: literal, $name: literal, $plugin_type: ident < $generic: ident >) => { ... };
($group: literal, $name: expr, $plugin_type: ident) => { ... };
}Expand description
Register a plugin with a group and a name Grouping prevent name clashes for plugins, so choose something unique, like your domain name. Plugins will appear in the configuration as a layer property called: {group}.{name}