PluginInit

Struct PluginInit 

#[non_exhaustive]
pub struct PluginInit<T> { pub config: T, pub supergraph_sdl: Arc<String>, /* private fields */ }
Initialise details for a plugin

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
config: T

Configuration

supergraph_sdl: Arc<String>

Router Supergraph Schema (schema definition language)

Implementations

Source

impl<T> PluginInit<T>
where T: for<'de> Deserialize<'de>,

pub fn new(config: T, supergraph_sdl: Arc<String>) -> Self

๐Ÿ‘ŽDeprecated:

use PluginInit::builder() instead

Create a new PluginInit for the supplied config and SDL.

pub fn try_new( config: Value, supergraph_sdl: Arc<String>, ) -> Result<Self, BoxError>

๐Ÿ‘ŽDeprecated:

use PluginInit::try_builder() instead

Try to create a new PluginInit for the supplied JSON and SDL.

This will fail if the supplied JSON cannot be deserialized into the configuration struct.

Source

impl<T> PluginInit<T>
where T: for<'de> Deserialize<'de>,

pub fn builder() -> NewBuilderPluginInitBuilder<T>

Create a new PluginInit builder Build a new PluginInit for the supplied configuration and SDL.

You can reuse a notify instance, or Build your own.

Source

impl<T> PluginInit<T>
where T: for<'de> Deserialize<'de>,

pub fn try_builder() -> TryNewBuilderPluginInitBuilder<T>

Try to build a new PluginInit for the supplied json configuration and SDL.

You can reuse a notify instance, or Build your own. invoking build() will fail if the JSON doesnโ€™t comply with the configuration format.

Source

impl<T> PluginInit<T>
where T: for<'de> Deserialize<'de>,

pub fn fake_builder() -> FakeNewBuilderPluginInitBuilder<T>

Create a new PluginInit builder

Source

impl PluginInit<Value>

pub fn with_deserialized_config<T>(self) -> Result<PluginInit<T>, BoxError>
where T: for<'de> Deserialize<'de>,

Attempts to convert the plugin configuration from serde_json::Value to the desired type T