Struct apollo_router::plugin::test::MockExecutionService
source · pub struct MockExecutionService { /* private fields */ }Implementations
sourceimpl MockExecutionService
impl MockExecutionService
pub fn call( &mut self, req: ExecutionRequest ) -> Result<ExecutionResponse, BoxError>
sourcepub fn expect_call(&mut self) -> &mut Expectation
pub fn expect_call(&mut self) -> &mut Expectation
Create an Expectation for mocking the call method
sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
sourceimpl MockExecutionService
impl MockExecutionService
sourcepub fn expect_clone(&mut self) -> &mut Expectation
pub fn expect_clone(&mut self) -> &mut Expectation
Create an Expectation for mocking the clone method