#[non_exhaustive]pub struct Request {
pub supergraph_request: Request<Request>,
pub query_plan: Arc<QueryPlan>,
pub context: Context,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.supergraph_request: Request<Request>Original request to the Router.
query_plan: Arc<QueryPlan>context: ContextImplementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> NewRequestBuilder
pub fn builder() -> NewRequestBuilder
This is the constructor (or builder) to use when constructing a real ExecutionRequest.
The parameters are not optional, because in a live situation all of these properties must be set and be correct to create a ExecutionRequest.
Sourceimpl Request
impl Request
Sourcepub fn fake_builder() -> FakeNewRequestBuilder
pub fn fake_builder() -> FakeNewRequestBuilder
This is the constructor (or builder) to use when constructing a “fake” ExecutionRequest.
This does not enforce the provision of the data that is required for a fully functional ExecutionRequest. It’s usually enough for testing, when a fully constructed ExecutionRequest is difficult to construct and not required for the purposes of the test.
Example
use apollo_router::services::execution;
use apollo_router::Context;
// This builder must remain usable from external crates for plugin testing.
let request = execution::Request::fake_builder()
.context(Context::default())
.build();Trait Implementations
Sourceimpl Service<Request> for MockExecutionService
impl Service<Request> for MockExecutionService
Sourcetype Future = Pin<Box<dyn Future<Output = Result<<MockExecutionService as Service<Request>>::Response, <MockExecutionService as Service<Request>>::Error>> + Send>>
type Future = Pin<Box<dyn Future<Output = Result<<MockExecutionService as Service<Request>>::Response, <MockExecutionService as Service<Request>>::Error>> + Send>>