pub struct TryIntoHeaderName { /* private fields */ }Expand description
Delayed-fallibility wrapper for conversion to http::header::HeaderName.
buildstructor builders allow doing implicit conversions for convenience,
but only infallible ones.
HeaderName can be converted from various types but the conversions is often fallible,
with TryFrom or TryInto instead of From or Into.
This types splits conversion in two steps:
it implements infallible conversion from various types like &str (that builders can rely on)
and fallible conversion to HeaderName (called later where we can handle errors).
See for example supergraph::Request::builder
which can be used like this:
use apollo_router::services::supergraph;
let request = supergraph::Request::fake_builder()
.header("accept-encoding", "gzip")
// Other parameters
.build()?;Trait Implementations
impl Eq for TryIntoHeaderName
Sourceimpl From<&HeaderName> for TryIntoHeaderName
impl From<&HeaderName> for TryIntoHeaderName
Sourcefn from(value: &HeaderName) -> Self
fn from(value: &HeaderName) -> Self
Sourceimpl From<&[u8]> for TryIntoHeaderName
impl From<&[u8]> for TryIntoHeaderName
Sourceimpl From<&str> for TryIntoHeaderName
impl From<&str> for TryIntoHeaderName
Sourceimpl From<HeaderName> for TryIntoHeaderName
impl From<HeaderName> for TryIntoHeaderName
Sourcefn from(value: HeaderName) -> Self
fn from(value: HeaderName) -> Self
Sourceimpl From<String> for TryIntoHeaderName
impl From<String> for TryIntoHeaderName
Sourceimpl Hash for TryIntoHeaderName
impl Hash for TryIntoHeaderName
Sourceimpl PartialEq for TryIntoHeaderName
impl PartialEq for TryIntoHeaderName
Sourceimpl TryFrom<TryIntoHeaderName> for HeaderName
impl TryFrom<TryIntoHeaderName> for HeaderName
Sourcetype Error = InvalidHeaderName
type Error = InvalidHeaderName