SubgraphRequestId

Struct SubgraphRequestId 

pub struct SubgraphRequestId(pub String);
unique id for a subgraph request and the related response

Tuple Fields

0: String

Implementations

Methods from Deref<Target = str>

1.0.0 ยท Source

pub fn len(&self) -> usize

Returns the length of self.

This length is in bytes, not chars or graphemes. In other words, it might not be what a human considers the length of the string.

Examples
let len = "foo".len();
assert_eq!(3, len);

assert_eq!("ฦ’oo".len(), 4); // fancy f!
assert_eq!("ฦ’oo".chars().count(), 3);
1.0.0 ยท Source

pub fn is_empty(&self) -> bool

Returns true if self has a length of zero bytes.

Examples
let s = "";
assert!(s.is_empty());

let s = "not empty";
assert!(!s.is_empty());
1.9.0 ยท Source

pub fn is_char_boundary(&self, index: usize) -> bool

Checks that index-th byte is the first byte in a UTF-8 code point sequence or the end of the string.

The start and end of the string (when index == self.len()) are considered to be boundaries.

Returns false if index is greater than self.len().

Examples
let s = "Lรถwe ่€่™Ž Lรฉopard";
assert!(s.is_char_boundary(0));
// start of `่€`
assert!(s.is_char_boundary(6));
assert!(s.is_char_boundary(s.len()));

// second byte of `รถ`
assert!(!s.is_char_boundary(2));

// third byte of `่€`
assert!(!s.is_char_boundary(8));
1.91.0 ยท Source

pub fn floor_char_boundary(&self, index: usize) -> usize

Finds the closest x not exceeding index where is_char_boundary(x) is true.

This method can help you truncate a string so that itโ€™s still valid UTF-8, but doesnโ€™t exceed a given number of bytes. Note that this is done purely at the character level and can still visually split graphemes, even though the underlying characters arenโ€™t split. For example, the emoji ๐Ÿง‘โ€๐Ÿ”ฌ (scientist) could be split so that the string only includes ๐Ÿง‘ (person) instead.

Examples
let s = "โค๏ธ๐Ÿงก๐Ÿ’›๐Ÿ’š๐Ÿ’™๐Ÿ’œ";
assert_eq!(s.len(), 26);
assert!(!s.is_char_boundary(13));

let closest = s.floor_char_boundary(13);
assert_eq!(closest, 10);
assert_eq!(&s[..closest], "โค๏ธ๐Ÿงก");
1.91.0 ยท Source

pub fn ceil_char_boundary(&self, index: usize) -> usize

Finds the closest x not below index where is_char_boundary(x) is true.

If index is greater than the length of the string, this returns the length of the string.

This method is the natural complement to floor_char_boundary. See that method for more details.

Examples
let s = "โค๏ธ๐Ÿงก๐Ÿ’›๐Ÿ’š๐Ÿ’™๐Ÿ’œ";
assert_eq!(s.len(), 26);
assert!(!s.is_char_boundary(13));

let closest = s.ceil_char_boundary(13);
assert_eq!(closest, 14);
assert_eq!(&s[..closest], "โค๏ธ๐Ÿงก๐Ÿ’›");
1.0.0 ยท Source

pub fn as_bytes(&self) -> &[u8] โ“˜

Converts a string slice to a byte slice. To convert the byte slice back into a string slice, use the from_utf8 function.

Examples
let bytes = "bors".as_bytes();
assert_eq!(b"bors", bytes);
1.0.0 ยท Source

pub fn as_ptr(&self) -> *const u8

Converts a string slice to a raw pointer.

As string slices are a slice of bytes, the raw pointer points to a u8. This pointer will be pointing to the first byte of the string slice.

The caller must ensure that the returned pointer is never written to. If you need to mutate the contents of the string slice, use as_mut_ptr.

Examples
let s = "Hello";
let ptr = s.as_ptr();
1.20.0 ยท Source

pub fn get<I>(&self, i: I) -> Option<&<I as SliceIndex<str>>::Output>
where I: SliceIndex<str>,

Returns a subslice of str.

This is the non-panicking alternative to indexing the str. Returns None whenever equivalent indexing operation would panic.

Examples
let v = String::from("๐Ÿ—ปโˆˆ๐ŸŒ");

assert_eq!(Some("๐Ÿ—ป"), v.get(0..4));

// indices not on UTF-8 sequence boundaries
assert!(v.get(1..).is_none());
assert!(v.get(..8).is_none());

// out of bounds
assert!(v.get(..42).is_none());
1.20.0 ยท Source

pub unsafe fn get_unchecked<I>(&self, i: I) -> &<I as SliceIndex<str>>::Output
where I: SliceIndex<str>,

Returns an unchecked subslice of str.

This is the unchecked alternative to indexing the str.

Safety

Callers of this function are responsible that these preconditions are satisfied:

  • The starting index must not exceed the ending index;
  • Indexes must be within bounds of the original slice;
  • Indexes must lie on UTF-8 sequence boundaries.

Failing that, the returned string slice may reference invalid memory or violate the invariants communicated by the str type.

Examples
let v = "๐Ÿ—ปโˆˆ๐ŸŒ";
unsafe {
    assert_eq!("๐Ÿ—ป", v.get_unchecked(0..4));
    assert_eq!("โˆˆ", v.get_unchecked(4..7));
    assert_eq!("๐ŸŒ", v.get_unchecked(7..11));
}
1.0.0 ยท Source

pub unsafe fn slice_unchecked(&self, begin: usize, end: usize) -> &str

๐Ÿ‘ŽDeprecated since 1.29.0:

use get_unchecked(begin..end) instead

Creates a string slice from another string slice, bypassing safety checks.

This is generally not recommended, use with caution! For a safe alternative see str and Index.

This new slice goes from begin to end, including begin but excluding end.

To get a mutable string slice instead, see the slice_mut_unchecked method.

Safety

Callers of this function are responsible that three preconditions are satisfied:

  • begin must not exceed end.
  • begin and end must be byte positions within the string slice.
  • begin and end must lie on UTF-8 sequence boundaries.
Examples
let s = "Lรถwe ่€่™Ž Lรฉopard";

unsafe {
    assert_eq!("Lรถwe ่€่™Ž Lรฉopard", s.slice_unchecked(0, 21));
}

let s = "Hello, world!";

unsafe {
    assert_eq!("world", s.slice_unchecked(7, 12));
}
1.4.0 ยท Source

pub fn split_at(&self, mid: usize) -> (&str, &str)

Divides one string slice into two at an index.

The argument, mid, should be a byte offset from the start of the string. It must also be on the boundary of a UTF-8 code point.

The two slices returned go from the start of the string slice to mid, and from mid to the end of the string slice.

To get mutable string slices instead, see the split_at_mut method.

Panics

Panics if mid is not on a UTF-8 code point boundary, or if it is past the end of the last code point of the string slice. For a non-panicking alternative see split_at_checked.

Examples
let s = "Per Martin-Lรถf";

let (first, last) = s.split_at(3);

assert_eq!("Per", first);
assert_eq!(" Martin-Lรถf", last);
1.80.0 ยท Source

pub fn split_at_checked(&self, mid: usize) -> Option<(&str, &str)>

Divides one string slice into two at an index.

The argument, mid, should be a valid byte offset from the start of the string. It must also be on the boundary of a UTF-8 code point. The method returns None if thatโ€™s not the case.

The two slices returned go from the start of the string slice to mid, and from mid to the end of the string slice.

To get mutable string slices instead, see the split_at_mut_checked method.

Examples
let s = "Per Martin-Lรถf";

let (first, last) = s.split_at_checked(3).unwrap();
assert_eq!("Per", first);
assert_eq!(" Martin-Lรถf", last);

assert_eq!(None, s.split_at_checked(13));  // Inside โ€œรถโ€
assert_eq!(None, s.split_at_checked(16));  // Beyond the string length
1.0.0 ยท Source

pub fn chars(&self) -> Chars<'_>

Returns an iterator over the chars of a string slice.

As a string slice consists of valid UTF-8, we can iterate through a string slice by char. This method returns such an iterator.

Itโ€™s important to remember that char represents a Unicode Scalar Value, and might not match your idea of what a โ€˜characterโ€™ is. Iteration over grapheme clusters may be what you actually want. This functionality is not provided by Rustโ€™s standard library, check crates.io instead.

Examples

Basic usage:

let word = "goodbye";

let count = word.chars().count();
assert_eq!(7, count);

let mut chars = word.chars();

assert_eq!(Some('g'), chars.next());
assert_eq!(Some('o'), chars.next());
assert_eq!(Some('o'), chars.next());
assert_eq!(Some('d'), chars.next());
assert_eq!(Some('b'), chars.next());
assert_eq!(Some('y'), chars.next());
assert_eq!(Some('e'), chars.next());

assert_eq!(None, chars.next());

Remember, chars might not match your intuition about characters:

let y = "yฬ†";

let mut chars = y.chars();

assert_eq!(Some('y'), chars.next()); // not 'yฬ†'
assert_eq!(Some('\u{0306}'), chars.next());

assert_eq!(None, chars.next());
1.0.0 ยท Source

pub fn char_indices(&self) -> CharIndices<'_>

Returns an iterator over the chars of a string slice, and their positions.

As a string slice consists of valid UTF-8, we can iterate through a string slice by char. This method returns an iterator of both these chars, as well as their byte positions.

The iterator yields tuples. The position is first, the char is second.

Examples

Basic usage:

let word = "goodbye";

let count = word.char_indices().count();
assert_eq!(7, count);

let mut char_indices = word.char_indices();

assert_eq!(Some((0, 'g')), char_indices.next());
assert_eq!(Some((1, 'o')), char_indices.next());
assert_eq!(Some((2, 'o')), char_indices.next());
assert_eq!(Some((3, 'd')), char_indices.next());
assert_eq!(Some((4, 'b')), char_indices.next());
assert_eq!(Some((5, 'y')), char_indices.next());
assert_eq!(Some((6, 'e')), char_indices.next());

assert_eq!(None, char_indices.next());

Remember, chars might not match your intuition about characters:

let yes = "yฬ†es";

let mut char_indices = yes.char_indices();

assert_eq!(Some((0, 'y')), char_indices.next()); // not (0, 'yฬ†')
assert_eq!(Some((1, '\u{0306}')), char_indices.next());

// note the 3 here - the previous character took up two bytes
assert_eq!(Some((3, 'e')), char_indices.next());
assert_eq!(Some((4, 's')), char_indices.next());

assert_eq!(None, char_indices.next());
1.0.0 ยท Source

pub fn bytes(&self) -> Bytes<'_>

Returns an iterator over the bytes of a string slice.

As a string slice consists of a sequence of bytes, we can iterate through a string slice by byte. This method returns such an iterator.

Examples
let mut bytes = "bors".bytes();

assert_eq!(Some(b'b'), bytes.next());
assert_eq!(Some(b'o'), bytes.next());
assert_eq!(Some(b'r'), bytes.next());
assert_eq!(Some(b's'), bytes.next());

assert_eq!(None, bytes.next());
1.1.0 ยท Source

pub fn split_whitespace(&self) -> SplitWhitespace<'_>

Splits a string slice by whitespace.

The iterator returned will return string slices that are sub-slices of the original string slice, separated by any amount of whitespace.

โ€˜Whitespaceโ€™ is defined according to the terms of the Unicode Derived Core Property White_Space. If you only want to split on ASCII whitespace instead, use split_ascii_whitespace.

Examples

Basic usage:

let mut iter = "A few words".split_whitespace();

assert_eq!(Some("A"), iter.next());
assert_eq!(Some("few"), iter.next());
assert_eq!(Some("words"), iter.next());

assert_eq!(None, iter.next());

All kinds of whitespace are considered:

let mut iter = " Mary   had\ta\u{2009}little  \n\t lamb".split_whitespace();
assert_eq!(Some("Mary"), iter.next());
assert_eq!(Some("had"), iter.next());
assert_eq!(Some("a"), iter.next());
assert_eq!(Some("little"), iter.next());
assert_eq!(Some("lamb"), iter.next());

assert_eq!(None, iter.next());

If the string is empty or all whitespace, the iterator yields no string slices:

assert_eq!("".split_whitespace().next(), None);
assert_eq!("   ".split_whitespace().next(), None);
1.34.0 ยท Source

pub fn split_ascii_whitespace(&self) -> SplitAsciiWhitespace<'_>

Splits a string slice by ASCII whitespace.

The iterator returned will return string slices that are sub-slices of the original string slice, separated by any amount of ASCII whitespace.

This uses the same definition as char::is_ascii_whitespace. To split by Unicode Whitespace instead, use split_whitespace. Note that because of this difference in definition, even if s.is_ascii() is true, s.split_ascii_whitespace() behavior will differ from s.split_whitespace() if s contains U+000B VERTICAL TAB.

Examples

Basic usage:

let mut iter = "A few words".split_ascii_whitespace();

assert_eq!(Some("A"), iter.next());
assert_eq!(Some("few"), iter.next());
assert_eq!(Some("words"), iter.next());

assert_eq!(None, iter.next());

Various kinds of ASCII whitespace are considered (see char::is_ascii_whitespace):

let mut iter = " Mary   had\ta little  \n\t lamb".split_ascii_whitespace();
assert_eq!(Some("Mary"), iter.next());
assert_eq!(Some("had"), iter.next());
assert_eq!(Some("a"), iter.next());
assert_eq!(Some("little"), iter.next());
assert_eq!(Some("lamb"), iter.next());

assert_eq!(None, iter.next());

If the string is empty or all ASCII whitespace, the iterator yields no string slices:

assert_eq!("".split_ascii_whitespace().next(), None);
assert_eq!("   ".split_ascii_whitespace().next(), None);
1.0.0 ยท Source

pub fn lines(&self) -> Lines<'_>

Returns an iterator over the lines of a string, as string slices.

Lines are split at line endings that are either newlines (\n) or sequences of a carriage return followed by a line feed (\r\n).

Line terminators are not included in the lines returned by the iterator.

Note that any carriage return (\r) not immediately followed by a line feed (\n) does not split a line. These carriage returns are thereby included in the produced lines.

The final line ending is optional. A string that ends with a final line ending will return the same lines as an otherwise identical string without a final line ending.

An empty string returns an empty iterator.

Examples

Basic usage:

let text = "foo\r\nbar\n\nbaz\r";
let mut lines = text.lines();

assert_eq!(Some("foo"), lines.next());
assert_eq!(Some("bar"), lines.next());
assert_eq!(Some(""), lines.next());
// Trailing carriage return is included in the last line
assert_eq!(Some("baz\r"), lines.next());

assert_eq!(None, lines.next());

The final line does not require any ending:

let text = "foo\nbar\n\r\nbaz";
let mut lines = text.lines();

assert_eq!(Some("foo"), lines.next());
assert_eq!(Some("bar"), lines.next());
assert_eq!(Some(""), lines.next());
assert_eq!(Some("baz"), lines.next());

assert_eq!(None, lines.next());

An empty string returns an empty iterator:

let text = "";
let mut lines = text.lines();

assert_eq!(lines.next(), None);
1.0.0 ยท Source

pub fn lines_any(&self) -> LinesAny<'_>

๐Ÿ‘ŽDeprecated since 1.4.0:

use lines() instead now

Returns an iterator over the lines of a string.

1.8.0 ยท Source

pub fn encode_utf16(&self) -> EncodeUtf16<'_>

Returns an iterator of u16 over the string encoded as native endian UTF-16 (without byte-order mark).

Examples
let text = "Zaลผรณล‚ฤ‡ gฤ™ล›lฤ… jaลบล„";

let utf8_len = text.len();
let utf16_len = text.encode_utf16().count();

assert!(utf16_len <= utf8_len);
1.0.0 ยท Source

pub fn contains<P>(&self, pat: P) -> bool
where P: Pattern,

Returns true if the given pattern matches a sub-slice of this string slice.

Returns false if it does not.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples
let bananas = "bananas";

assert!(bananas.contains("nana"));
assert!(!bananas.contains("apples"));
1.0.0 ยท Source

pub fn starts_with<P>(&self, pat: P) -> bool
where P: Pattern,

Returns true if the given pattern matches a prefix of this string slice.

Returns false if it does not.

The pattern can be a &str, in which case this function will return true if the &str is a prefix of this string slice.

The pattern can also be a char, a slice of chars, or a function or closure that determines if a character matches. These will only be checked against the first character of this string slice. Look at the second example below regarding behavior for slices of chars.

Examples
let bananas = "bananas";

assert!(bananas.starts_with("bana"));
assert!(!bananas.starts_with("nana"));
let bananas = "bananas";

// Note that both of these assert successfully.
assert!(bananas.starts_with(&['b', 'a', 'n', 'a']));
assert!(bananas.starts_with(&['a', 'b', 'c', 'd']));
1.0.0 ยท Source

pub fn ends_with<P>(&self, pat: P) -> bool
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns true if the given pattern matches a suffix of this string slice.

Returns false if it does not.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples
let bananas = "bananas";

assert!(bananas.ends_with("anas"));
assert!(!bananas.ends_with("nana"));
1.0.0 ยท Source

pub fn find<P>(&self, pat: P) -> Option<usize>
where P: Pattern,

Returns the byte index of the first character of this string slice that matches the pattern.

Returns None if the pattern doesnโ€™t match.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples

Simple patterns:

let s = "Lรถwe ่€่™Ž Lรฉopard Gepardi";

assert_eq!(s.find('L'), Some(0));
assert_eq!(s.find('รฉ'), Some(14));
assert_eq!(s.find("pard"), Some(17));

More complex patterns using point-free style and closures:

let s = "Lรถwe ่€่™Ž Lรฉopard";

assert_eq!(s.find(char::is_whitespace), Some(5));
assert_eq!(s.find(char::is_lowercase), Some(1));
assert_eq!(s.find(|c: char| c.is_whitespace() || c.is_lowercase()), Some(1));
assert_eq!(s.find(|c: char| (c < 'o') && (c > 'a')), Some(4));

Not finding the pattern:

let s = "Lรถwe ่€่™Ž Lรฉopard";
let x: &[_] = &['1', '2'];

assert_eq!(s.find(x), None);
1.0.0 ยท Source

pub fn rfind<P>(&self, pat: P) -> Option<usize>
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns the byte index for the first character of the last match of the pattern in this string slice.

Returns None if the pattern doesnโ€™t match.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples

Simple patterns:

let s = "Lรถwe ่€่™Ž Lรฉopard Gepardi";

assert_eq!(s.rfind('L'), Some(13));
assert_eq!(s.rfind('รฉ'), Some(14));
assert_eq!(s.rfind("pard"), Some(24));

More complex patterns with closures:

let s = "Lรถwe ่€่™Ž Lรฉopard";

assert_eq!(s.rfind(char::is_whitespace), Some(12));
assert_eq!(s.rfind(char::is_lowercase), Some(20));

Not finding the pattern:

let s = "Lรถwe ่€่™Ž Lรฉopard";
let x: &[_] = &['1', '2'];

assert_eq!(s.rfind(x), None);
1.0.0 ยท Source

pub fn split<P>(&self, pat: P) -> Split<'_, P>
where P: Pattern,

Returns an iterator over substrings of this string slice, separated by characters matched by a pattern.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

If there are no matches the full string slice is returned as the only item in the iterator.

Iterator behavior

The returned iterator will be a DoubleEndedIterator if the pattern allows a reverse search and forward/reverse search yields the same elements. This is true for, e.g., char, but not for &str.

If the pattern allows a reverse search but its results might differ from a forward search, the rsplit method can be used.

Examples

Simple patterns:

let v: Vec<&str> = "Mary had a little lamb".split(' ').collect();
assert_eq!(v, ["Mary", "had", "a", "little", "lamb"]);

let v: Vec<&str> = "".split('X').collect();
assert_eq!(v, [""]);

let v: Vec<&str> = "lionXXtigerXleopard".split('X').collect();
assert_eq!(v, ["lion", "", "tiger", "leopard"]);

let v: Vec<&str> = "lion::tiger::leopard".split("::").collect();
assert_eq!(v, ["lion", "tiger", "leopard"]);

let v: Vec<&str> = "AABBCC".split("DD").collect();
assert_eq!(v, ["AABBCC"]);

let v: Vec<&str> = "abc1def2ghi".split(char::is_numeric).collect();
assert_eq!(v, ["abc", "def", "ghi"]);

let v: Vec<&str> = "lionXtigerXleopard".split(char::is_uppercase).collect();
assert_eq!(v, ["lion", "tiger", "leopard"]);

If the pattern is a slice of chars, split on each occurrence of any of the characters:

let v: Vec<&str> = "2020-11-03 23:59".split(&['-', ' ', ':', '@'][..]).collect();
assert_eq!(v, ["2020", "11", "03", "23", "59"]);

A more complex pattern, using a closure:

let v: Vec<&str> = "abc1defXghi".split(|c| c == '1' || c == 'X').collect();
assert_eq!(v, ["abc", "def", "ghi"]);

If a string contains multiple contiguous separators, you will end up with empty strings in the output:

let x = "||||a||b|c".to_string();
let d: Vec<_> = x.split('|').collect();

assert_eq!(d, &["", "", "", "", "a", "", "b", "c"]);

Contiguous separators are separated by the empty string.

let x = "(///)".to_string();
let d: Vec<_> = x.split('/').collect();

assert_eq!(d, &["(", "", "", ")"]);

Separators at the start or end of a string are neighbored by empty strings.

let d: Vec<_> = "010".split("0").collect();
assert_eq!(d, &["", "1", ""]);

When the empty string is used as a separator, it separates every character in the string, along with the beginning and end of the string.

let f: Vec<_> = "rust".split("").collect();
assert_eq!(f, &["", "r", "u", "s", "t", ""]);

Contiguous separators can lead to possibly surprising behavior when whitespace is used as the separator. This code is correct:

let x = "    a  b c".to_string();
let d: Vec<_> = x.split(' ').collect();

assert_eq!(d, &["", "", "", "", "a", "", "b", "c"]);

It does not give you:

โ“˜
assert_eq!(d, &["a", "b", "c"]);

Use split_whitespace for this behavior.

1.51.0 ยท Source

pub fn split_inclusive<P>(&self, pat: P) -> SplitInclusive<'_, P>
where P: Pattern,

Returns an iterator over substrings of this string slice, separated by characters matched by a pattern.

Differs from the iterator produced by split in that split_inclusive leaves the matched part as the terminator of the substring.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples
let v: Vec<&str> = "Mary had a little lamb\nlittle lamb\nlittle lamb."
    .split_inclusive('\n').collect();
assert_eq!(v, ["Mary had a little lamb\n", "little lamb\n", "little lamb."]);

If the last element of the string is matched, that element will be considered the terminator of the preceding substring. That substring will be the last item returned by the iterator.

let v: Vec<&str> = "Mary had a little lamb\nlittle lamb\nlittle lamb.\n"
    .split_inclusive('\n').collect();
assert_eq!(v, ["Mary had a little lamb\n", "little lamb\n", "little lamb.\n"]);
1.0.0 ยท Source

pub fn rsplit<P>(&self, pat: P) -> RSplit<'_, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns an iterator over substrings of the given string slice, separated by characters matched by a pattern and yielded in reverse order.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Iterator behavior

The returned iterator requires that the pattern supports a reverse search, and it will be a DoubleEndedIterator if a forward/reverse search yields the same elements.

For iterating from the front, the split method can be used.

Examples

Simple patterns:

let v: Vec<&str> = "Mary had a little lamb".rsplit(' ').collect();
assert_eq!(v, ["lamb", "little", "a", "had", "Mary"]);

let v: Vec<&str> = "".rsplit('X').collect();
assert_eq!(v, [""]);

let v: Vec<&str> = "lionXXtigerXleopard".rsplit('X').collect();
assert_eq!(v, ["leopard", "tiger", "", "lion"]);

let v: Vec<&str> = "lion::tiger::leopard".rsplit("::").collect();
assert_eq!(v, ["leopard", "tiger", "lion"]);

A more complex pattern, using a closure:

let v: Vec<&str> = "abc1defXghi".rsplit(|c| c == '1' || c == 'X').collect();
assert_eq!(v, ["ghi", "def", "abc"]);
1.0.0 ยท Source

pub fn split_terminator<P>(&self, pat: P) -> SplitTerminator<'_, P>
where P: Pattern,

Returns an iterator over substrings of the given string slice, separated by characters matched by a pattern.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Equivalent to split, except that the trailing substring is skipped if empty.

This method can be used for string data that is terminated, rather than separated by a pattern.

Iterator behavior

The returned iterator will be a DoubleEndedIterator if the pattern allows a reverse search and forward/reverse search yields the same elements. This is true for, e.g., char, but not for &str.

If the pattern allows a reverse search but its results might differ from a forward search, the rsplit_terminator method can be used.

Examples
let v: Vec<&str> = "A.B.".split_terminator('.').collect();
assert_eq!(v, ["A", "B"]);

let v: Vec<&str> = "A..B..".split_terminator(".").collect();
assert_eq!(v, ["A", "", "B", ""]);

let v: Vec<&str> = "A.B:C.D".split_terminator(&['.', ':'][..]).collect();
assert_eq!(v, ["A", "B", "C", "D"]);
1.0.0 ยท Source

pub fn rsplit_terminator<P>(&self, pat: P) -> RSplitTerminator<'_, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns an iterator over substrings of self, separated by characters matched by a pattern and yielded in reverse order.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Equivalent to split, except that the trailing substring is skipped if empty.

This method can be used for string data that is terminated, rather than separated by a pattern.

Iterator behavior

The returned iterator requires that the pattern supports a reverse search, and it will be double ended if a forward/reverse search yields the same elements.

For iterating from the front, the split_terminator method can be used.

Examples
let v: Vec<&str> = "A.B.".rsplit_terminator('.').collect();
assert_eq!(v, ["B", "A"]);

let v: Vec<&str> = "A..B..".rsplit_terminator(".").collect();
assert_eq!(v, ["", "B", "", "A"]);

let v: Vec<&str> = "A.B:C.D".rsplit_terminator(&['.', ':'][..]).collect();
assert_eq!(v, ["D", "C", "B", "A"]);
1.0.0 ยท Source

pub fn splitn<P>(&self, n: usize, pat: P) -> SplitN<'_, P>
where P: Pattern,

Returns an iterator over substrings of the given string slice, separated by a pattern, restricted to returning at most n items.

If n substrings are returned, the last substring (the nth substring) will contain the remainder of the string.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Iterator behavior

The returned iterator will not be double ended, because it is not efficient to support.

If the pattern allows a reverse search, the rsplitn method can be used.

Examples

Simple patterns:

let v: Vec<&str> = "Mary had a little lambda".splitn(3, ' ').collect();
assert_eq!(v, ["Mary", "had", "a little lambda"]);

let v: Vec<&str> = "lionXXtigerXleopard".splitn(3, "X").collect();
assert_eq!(v, ["lion", "", "tigerXleopard"]);

let v: Vec<&str> = "abcXdef".splitn(1, 'X').collect();
assert_eq!(v, ["abcXdef"]);

let v: Vec<&str> = "".splitn(1, 'X').collect();
assert_eq!(v, [""]);

A more complex pattern, using a closure:

let v: Vec<&str> = "abc1defXghi".splitn(2, |c| c == '1' || c == 'X').collect();
assert_eq!(v, ["abc", "defXghi"]);
1.0.0 ยท Source

pub fn rsplitn<P>(&self, n: usize, pat: P) -> RSplitN<'_, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns an iterator over substrings of this string slice, separated by a pattern, starting from the end of the string, restricted to returning at most n items.

If n substrings are returned, the last substring (the nth substring) will contain the remainder of the string.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Iterator behavior

The returned iterator will not be double ended, because it is not efficient to support.

For splitting from the front, the splitn method can be used.

Examples

Simple patterns:

let v: Vec<&str> = "Mary had a little lamb".rsplitn(3, ' ').collect();
assert_eq!(v, ["lamb", "little", "Mary had a"]);

let v: Vec<&str> = "lionXXtigerXleopard".rsplitn(3, 'X').collect();
assert_eq!(v, ["leopard", "tiger", "lionX"]);

let v: Vec<&str> = "lion::tiger::leopard".rsplitn(2, "::").collect();
assert_eq!(v, ["leopard", "lion::tiger"]);

A more complex pattern, using a closure:

let v: Vec<&str> = "abc1defXghi".rsplitn(2, |c| c == '1' || c == 'X').collect();
assert_eq!(v, ["ghi", "abc1def"]);
1.52.0 ยท Source

pub fn split_once<P>(&self, delimiter: P) -> Option<(&str, &str)>
where P: Pattern,

Splits the string on the first occurrence of the specified delimiter and returns prefix before delimiter and suffix after delimiter.

Examples
assert_eq!("cfg".split_once('='), None);
assert_eq!("cfg=".split_once('='), Some(("cfg", "")));
assert_eq!("cfg=foo".split_once('='), Some(("cfg", "foo")));
assert_eq!("cfg=foo=bar".split_once('='), Some(("cfg", "foo=bar")));
1.52.0 ยท Source

pub fn rsplit_once<P>(&self, delimiter: P) -> Option<(&str, &str)>
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Splits the string on the last occurrence of the specified delimiter and returns prefix before delimiter and suffix after delimiter.

Examples
assert_eq!("cfg".rsplit_once('='), None);
assert_eq!("cfg=".rsplit_once('='), Some(("cfg", "")));
assert_eq!("cfg=foo".rsplit_once('='), Some(("cfg", "foo")));
assert_eq!("cfg=foo=bar".rsplit_once('='), Some(("cfg=foo", "bar")));
1.2.0 ยท Source

pub fn matches<P>(&self, pat: P) -> Matches<'_, P>
where P: Pattern,

Returns an iterator over the disjoint matches of a pattern within the given string slice.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Iterator behavior

The returned iterator will be a DoubleEndedIterator if the pattern allows a reverse search and forward/reverse search yields the same elements. This is true for, e.g., char, but not for &str.

If the pattern allows a reverse search but its results might differ from a forward search, the rmatches method can be used.

Examples
let v: Vec<&str> = "abcXXXabcYYYabc".matches("abc").collect();
assert_eq!(v, ["abc", "abc", "abc"]);

let v: Vec<&str> = "1abc2abc3".matches(char::is_numeric).collect();
assert_eq!(v, ["1", "2", "3"]);
1.2.0 ยท Source

pub fn rmatches<P>(&self, pat: P) -> RMatches<'_, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns an iterator over the disjoint matches of a pattern within this string slice, yielded in reverse order.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Iterator behavior

The returned iterator requires that the pattern supports a reverse search, and it will be a DoubleEndedIterator if a forward/reverse search yields the same elements.

For iterating from the front, the matches method can be used.

Examples
let v: Vec<&str> = "abcXXXabcYYYabc".rmatches("abc").collect();
assert_eq!(v, ["abc", "abc", "abc"]);

let v: Vec<&str> = "1abc2abc3".rmatches(char::is_numeric).collect();
assert_eq!(v, ["3", "2", "1"]);
1.5.0 ยท Source

pub fn match_indices<P>(&self, pat: P) -> MatchIndices<'_, P>
where P: Pattern,

Returns an iterator over the disjoint matches of a pattern within this string slice as well as the index that the match starts at.

For matches of pat within self that overlap, only the indices corresponding to the first match are returned.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Iterator behavior

The returned iterator will be a DoubleEndedIterator if the pattern allows a reverse search and forward/reverse search yields the same elements. This is true for, e.g., char, but not for &str.

If the pattern allows a reverse search but its results might differ from a forward search, the rmatch_indices method can be used.

Examples
let v: Vec<_> = "abcXXXabcYYYabc".match_indices("abc").collect();
assert_eq!(v, [(0, "abc"), (6, "abc"), (12, "abc")]);

let v: Vec<_> = "1abcabc2".match_indices("abc").collect();
assert_eq!(v, [(1, "abc"), (4, "abc")]);

let v: Vec<_> = "ababa".match_indices("aba").collect();
assert_eq!(v, [(0, "aba")]); // only the first `aba`
1.5.0 ยท Source

pub fn rmatch_indices<P>(&self, pat: P) -> RMatchIndices<'_, P>
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns an iterator over the disjoint matches of a pattern within self, yielded in reverse order along with the index of the match.

For matches of pat within self that overlap, only the indices corresponding to the last match are returned.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Iterator behavior

The returned iterator requires that the pattern supports a reverse search, and it will be a DoubleEndedIterator if a forward/reverse search yields the same elements.

For iterating from the front, the match_indices method can be used.

Examples
let v: Vec<_> = "abcXXXabcYYYabc".rmatch_indices("abc").collect();
assert_eq!(v, [(12, "abc"), (6, "abc"), (0, "abc")]);

let v: Vec<_> = "1abcabc2".rmatch_indices("abc").collect();
assert_eq!(v, [(4, "abc"), (1, "abc")]);

let v: Vec<_> = "ababa".rmatch_indices("aba").collect();
assert_eq!(v, [(2, "aba")]); // only the last `aba`
1.0.0 ยท Source

pub fn trim(&self) -> &str

Returns a string slice with leading and trailing whitespace removed.

โ€˜Whitespaceโ€™ is defined according to the terms of the Unicode Derived Core Property White_Space, which includes newlines.

Examples
let s = "\n Hello\tworld\t\n";

assert_eq!("Hello\tworld", s.trim());
1.30.0 ยท Source

pub fn trim_start(&self) -> &str

Returns a string slice with leading whitespace removed.

โ€˜Whitespaceโ€™ is defined according to the terms of the Unicode Derived Core Property White_Space, which includes newlines.

Text directionality

A string is a sequence of bytes. start in this context means the first position of that byte string; for a left-to-right language like English or Russian, this will be left side, and for right-to-left languages like Arabic or Hebrew, this will be the right side.

Examples

Basic usage:

let s = "\n Hello\tworld\t\n";
assert_eq!("Hello\tworld\t\n", s.trim_start());

Directionality:

let s = "  English  ";
assert!(Some('E') == s.trim_start().chars().next());

let s = "  ืขื‘ืจื™ืช  ";
assert!(Some('ืข') == s.trim_start().chars().next());
1.30.0 ยท Source

pub fn trim_end(&self) -> &str

Returns a string slice with trailing whitespace removed.

โ€˜Whitespaceโ€™ is defined according to the terms of the Unicode Derived Core Property White_Space, which includes newlines.

Text directionality

A string is a sequence of bytes. end in this context means the last position of that byte string; for a left-to-right language like English or Russian, this will be right side, and for right-to-left languages like Arabic or Hebrew, this will be the left side.

Examples

Basic usage:

let s = "\n Hello\tworld\t\n";
assert_eq!("\n Hello\tworld", s.trim_end());

Directionality:

let s = "  English  ";
assert!(Some('h') == s.trim_end().chars().rev().next());

let s = "  ืขื‘ืจื™ืช  ";
assert!(Some('ืช') == s.trim_end().chars().rev().next());
1.0.0 ยท Source

pub fn trim_left(&self) -> &str

๐Ÿ‘ŽDeprecated since 1.33.0:

superseded by trim_start

Returns a string slice with leading whitespace removed.

โ€˜Whitespaceโ€™ is defined according to the terms of the Unicode Derived Core Property White_Space.

Text directionality

A string is a sequence of bytes. โ€˜Leftโ€™ in this context means the first position of that byte string; for a language like Arabic or Hebrew which are โ€˜right to leftโ€™ rather than โ€˜left to rightโ€™, this will be the right side, not the left.

Examples

Basic usage:

let s = " Hello\tworld\t";

assert_eq!("Hello\tworld\t", s.trim_left());

Directionality:

let s = "  English";
assert!(Some('E') == s.trim_left().chars().next());

let s = "  ืขื‘ืจื™ืช";
assert!(Some('ืข') == s.trim_left().chars().next());
1.0.0 ยท Source

pub fn trim_right(&self) -> &str

๐Ÿ‘ŽDeprecated since 1.33.0:

superseded by trim_end

Returns a string slice with trailing whitespace removed.

โ€˜Whitespaceโ€™ is defined according to the terms of the Unicode Derived Core Property White_Space.

Text directionality

A string is a sequence of bytes. โ€˜Rightโ€™ in this context means the last position of that byte string; for a language like Arabic or Hebrew which are โ€˜right to leftโ€™ rather than โ€˜left to rightโ€™, this will be the left side, not the right.

Examples

Basic usage:

let s = " Hello\tworld\t";

assert_eq!(" Hello\tworld", s.trim_right());

Directionality:

let s = "English  ";
assert!(Some('h') == s.trim_right().chars().rev().next());

let s = "ืขื‘ืจื™ืช  ";
assert!(Some('ืช') == s.trim_right().chars().rev().next());
1.0.0 ยท Source

pub fn trim_matches<P>(&self, pat: P) -> &str
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> DoubleEndedSearcher<'a>,

Returns a string slice with all prefixes and suffixes that match a pattern repeatedly removed.

The pattern can be a char, a slice of chars, or a function or closure that determines if a character matches.

Examples

Simple patterns:

assert_eq!("11foo1bar11".trim_matches('1'), "foo1bar");
assert_eq!("123foo1bar123".trim_matches(char::is_numeric), "foo1bar");

let x: &[_] = &['1', '2'];
assert_eq!("12foo1bar12".trim_matches(x), "foo1bar");

A more complex pattern, using a closure:

assert_eq!("1foo1barXX".trim_matches(|c| c == '1' || c == 'X'), "foo1bar");
1.30.0 ยท Source

pub fn trim_start_matches<P>(&self, pat: P) -> &str
where P: Pattern,

Returns a string slice with all prefixes that match a pattern repeatedly removed.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Text directionality

A string is a sequence of bytes. start in this context means the first position of that byte string; for a left-to-right language like English or Russian, this will be left side, and for right-to-left languages like Arabic or Hebrew, this will be the right side.

Examples
assert_eq!("11foo1bar11".trim_start_matches('1'), "foo1bar11");
assert_eq!("123foo1bar123".trim_start_matches(char::is_numeric), "foo1bar123");

let x: &[_] = &['1', '2'];
assert_eq!("12foo1bar12".trim_start_matches(x), "foo1bar12");
1.45.0 ยท Source

pub fn strip_prefix<P>(&self, prefix: P) -> Option<&str>
where P: Pattern,

Returns a string slice with the prefix removed.

If the string starts with the pattern prefix, returns the substring after the prefix, wrapped in Some. Unlike trim_start_matches, this method removes the prefix exactly once.

If the string does not start with prefix, returns None.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples
assert_eq!("foo:bar".strip_prefix("foo:"), Some("bar"));
assert_eq!("foo:bar".strip_prefix("bar"), None);
assert_eq!("foofoo".strip_prefix("foo"), Some("foo"));
1.45.0 ยท Source

pub fn strip_suffix<P>(&self, suffix: P) -> Option<&str>
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns a string slice with the suffix removed.

If the string ends with the pattern suffix, returns the substring before the suffix, wrapped in Some. Unlike trim_end_matches, this method removes the suffix exactly once.

If the string does not end with suffix, returns None.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples
assert_eq!("bar:foo".strip_suffix(":foo"), Some("bar"));
assert_eq!("bar:foo".strip_suffix("bar"), None);
assert_eq!("foofoo".strip_suffix("foo"), Some("foo"));
pub fn strip_circumfix<P, S>(&self, prefix: P, suffix: S) -> Option<&str>
where P: Pattern, S: Pattern, <S as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

๐Ÿ”ฌThis is a nightly-only experimental API. (strip_circumfix)

Returns a string slice with the prefix and suffix removed.

If the string starts with the pattern prefix and ends with the pattern suffix, returns the substring after the prefix and before the suffix, wrapped in Some. Unlike trim_start_matches and trim_end_matches, this method removes both the prefix and suffix exactly once.

If the string does not start with prefix or does not end with suffix, returns None.

Each pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples
#![feature(strip_circumfix)]

assert_eq!("bar:hello:foo".strip_circumfix("bar:", ":foo"), Some("hello"));
assert_eq!("bar:foo".strip_circumfix("foo", "foo"), None);
assert_eq!("foo:bar;".strip_circumfix("foo:", ';'), Some("bar"));
pub fn trim_prefix<P>(&self, prefix: P) -> &str
where P: Pattern,

๐Ÿ”ฌThis is a nightly-only experimental API. (trim_prefix_suffix)

Returns a string slice with the optional prefix removed.

If the string starts with the pattern prefix, returns the substring after the prefix. Unlike strip_prefix, this method always returns &str for easy method chaining, instead of returning Option<&str>.

If the string does not start with prefix, returns the original string unchanged.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples
#![feature(trim_prefix_suffix)]

// Prefix present - removes it
assert_eq!("foo:bar".trim_prefix("foo:"), "bar");
assert_eq!("foofoo".trim_prefix("foo"), "foo");

// Prefix absent - returns original string
assert_eq!("foo:bar".trim_prefix("bar"), "foo:bar");

// Method chaining example
assert_eq!("<https://example.com/>".trim_prefix('<').trim_suffix('>'), "https://example.com/");
pub fn trim_suffix<P>(&self, suffix: P) -> &str
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

๐Ÿ”ฌThis is a nightly-only experimental API. (trim_prefix_suffix)

Returns a string slice with the optional suffix removed.

If the string ends with the pattern suffix, returns the substring before the suffix. Unlike strip_suffix, this method always returns &str for easy method chaining, instead of returning Option<&str>.

If the string does not end with suffix, returns the original string unchanged.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Examples
#![feature(trim_prefix_suffix)]

// Suffix present - removes it
assert_eq!("bar:foo".trim_suffix(":foo"), "bar");
assert_eq!("foofoo".trim_suffix("foo"), "foo");

// Suffix absent - returns original string
assert_eq!("bar:foo".trim_suffix("bar"), "bar:foo");

// Method chaining example
assert_eq!("<https://example.com/>".trim_prefix('<').trim_suffix('>'), "https://example.com/");
1.30.0 ยท Source

pub fn trim_end_matches<P>(&self, pat: P) -> &str
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

Returns a string slice with all suffixes that match a pattern repeatedly removed.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Text directionality

A string is a sequence of bytes. end in this context means the last position of that byte string; for a left-to-right language like English or Russian, this will be right side, and for right-to-left languages like Arabic or Hebrew, this will be the left side.

Examples

Simple patterns:

assert_eq!("11foo1bar11".trim_end_matches('1'), "11foo1bar");
assert_eq!("123foo1bar123".trim_end_matches(char::is_numeric), "123foo1bar");

let x: &[_] = &['1', '2'];
assert_eq!("12foo1bar12".trim_end_matches(x), "12foo1bar");

A more complex pattern, using a closure:

assert_eq!("1fooX".trim_end_matches(|c| c == '1' || c == 'X'), "1foo");
1.0.0 ยท Source

pub fn trim_left_matches<P>(&self, pat: P) -> &str
where P: Pattern,

๐Ÿ‘ŽDeprecated since 1.33.0:

superseded by trim_start_matches

Returns a string slice with all prefixes that match a pattern repeatedly removed.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Text directionality

A string is a sequence of bytes. โ€˜Leftโ€™ in this context means the first position of that byte string; for a language like Arabic or Hebrew which are โ€˜right to leftโ€™ rather than โ€˜left to rightโ€™, this will be the right side, not the left.

Examples
assert_eq!("11foo1bar11".trim_left_matches('1'), "foo1bar11");
assert_eq!("123foo1bar123".trim_left_matches(char::is_numeric), "foo1bar123");

let x: &[_] = &['1', '2'];
assert_eq!("12foo1bar12".trim_left_matches(x), "foo1bar12");
1.0.0 ยท Source

pub fn trim_right_matches<P>(&self, pat: P) -> &str
where P: Pattern, <P as Pattern>::Searcher<'a>: for<'a> ReverseSearcher<'a>,

๐Ÿ‘ŽDeprecated since 1.33.0:

superseded by trim_end_matches

Returns a string slice with all suffixes that match a pattern repeatedly removed.

The pattern can be a &str, char, a slice of chars, or a function or closure that determines if a character matches.

Text directionality

A string is a sequence of bytes. โ€˜Rightโ€™ in this context means the last position of that byte string; for a language like Arabic or Hebrew which are โ€˜right to leftโ€™ rather than โ€˜left to rightโ€™, this will be the left side, not the right.

Examples

Simple patterns:

assert_eq!("11foo1bar11".trim_right_matches('1'), "11foo1bar");
assert_eq!("123foo1bar123".trim_right_matches(char::is_numeric), "123foo1bar");

let x: &[_] = &['1', '2'];
assert_eq!("12foo1bar12".trim_right_matches(x), "12foo1bar");

A more complex pattern, using a closure:

assert_eq!("1fooX".trim_right_matches(|c| c == '1' || c == 'X'), "1foo");
1.0.0 ยท Source

pub fn parse<F>(&self) -> Result<F, <F as FromStr>::Err>
where F: FromStr,

Parses this string slice into another type.

Because parse is so general, it can cause problems with type inference. As such, parse is one of the few times youโ€™ll see the syntax affectionately known as the โ€˜turbofishโ€™: ::<>. This helps the inference algorithm understand specifically which type youโ€™re trying to parse into.

parse can parse into any type that implements the FromStr trait.

Errors

Will return Err if itโ€™s not possible to parse this string slice into the desired type.

Examples

Basic usage:

let four: u32 = "4".parse().unwrap();

assert_eq!(4, four);

Using the โ€˜turbofishโ€™ instead of annotating four:

let four = "4".parse::<u32>();

assert_eq!(Ok(4), four);

Failing to parse:

let nope = "j".parse::<u32>();

assert!(nope.is_err());
1.23.0 ยท Source

pub fn is_ascii(&self) -> bool

Checks if all characters in this string are within the ASCII range.

An empty string returns true.

Examples
let ascii = "hello!\n";
let non_ascii = "GrรผรŸe, Jรผrgen โค";

assert!(ascii.is_ascii());
assert!(!non_ascii.is_ascii());
pub fn as_ascii(&self) -> Option<&[AsciiChar]>

๐Ÿ”ฌThis is a nightly-only experimental API. (ascii_char)

If this string slice is_ascii, returns it as a slice of ASCII characters, otherwise returns None.

pub unsafe fn as_ascii_unchecked(&self) -> &[AsciiChar]

๐Ÿ”ฌThis is a nightly-only experimental API. (ascii_char)

Converts this string slice into a slice of ASCII characters, without checking whether they are valid.

Safety

Every character in this string must be ASCII, or else this is UB.

1.23.0 ยท Source

pub fn eq_ignore_ascii_case(&self, other: &str) -> bool

Checks that two strings are an ASCII case-insensitive match.

Same as to_ascii_lowercase(a) == to_ascii_lowercase(b), but without allocating and copying temporaries.

Examples
assert!("Ferris".eq_ignore_ascii_case("FERRIS"));
assert!("Ferrรถs".eq_ignore_ascii_case("FERRรถS"));
assert!(!"Ferrรถs".eq_ignore_ascii_case("FERRร–S"));
1.80.0 ยท Source

pub fn trim_ascii_start(&self) -> &str

Returns a string slice with leading ASCII whitespace removed.

โ€˜Whitespaceโ€™ refers to the definition used by u8::is_ascii_whitespace. Importantly, this definition excludes the U+000B code point even though it has the Unicode White_Space property and is removed by str::trim_start.

Examples
assert_eq!(" \t \u{3000}hello world\n".trim_ascii_start(), "\u{3000}hello world\n");
assert_eq!("  ".trim_ascii_start(), "");
assert_eq!("".trim_ascii_start(), "");
1.80.0 ยท Source

pub fn trim_ascii_end(&self) -> &str

Returns a string slice with trailing ASCII whitespace removed.

โ€˜Whitespaceโ€™ refers to the definition used by u8::is_ascii_whitespace. Importantly, this definition excludes the U+000B code point even though it has the Unicode White_Space property and is removed by str::trim_end.

Examples
assert_eq!("\r hello world\u{3000}\n ".trim_ascii_end(), "\r hello world\u{3000}");
assert_eq!("  ".trim_ascii_end(), "");
assert_eq!("".trim_ascii_end(), "");
1.80.0 ยท Source

pub fn trim_ascii(&self) -> &str

Returns a string slice with leading and trailing ASCII whitespace removed.

โ€˜Whitespaceโ€™ refers to the definition used by u8::is_ascii_whitespace. Importantly, this definition excludes the U+000B code point even though it has the Unicode White_Space property and is removed by str::trim.

Examples
assert_eq!("\r hello world\n ".trim_ascii(), "hello world");
assert_eq!("  ".trim_ascii(), "");
assert_eq!("".trim_ascii(), "");
1.34.0 ยท Source

pub fn escape_debug(&self) -> EscapeDebug<'_>

Returns an iterator that escapes each char in self with char::escape_debug.

Note: only extended grapheme codepoints that begin the string will be escaped.

Examples

As an iterator:

for c in "โค\n!".escape_debug() {
    print!("{c}");
}
println!();

Using println! directly:

println!("{}", "โค\n!".escape_debug());

Both are equivalent to:

println!("โค\\n!");

Using to_string:

assert_eq!("โค\n!".escape_debug().to_string(), "โค\\n!");
1.34.0 ยท Source

pub fn escape_default(&self) -> EscapeDefault<'_>

Returns an iterator that escapes each char in self with char::escape_default.

Examples

As an iterator:

for c in "โค\n!".escape_default() {
    print!("{c}");
}
println!();

Using println! directly:

println!("{}", "โค\n!".escape_default());

Both are equivalent to:

println!("\\u{{2764}}\\n!");

Using to_string:

assert_eq!("โค\n!".escape_default().to_string(), "\\u{2764}\\n!");
1.34.0 ยท Source

pub fn escape_unicode(&self) -> EscapeUnicode<'_>

Returns an iterator that escapes each char in self with char::escape_unicode.

Examples

As an iterator:

for c in "โค\n!".escape_unicode() {
    print!("{c}");
}
println!();

Using println! directly:

println!("{}", "โค\n!".escape_unicode());

Both are equivalent to:

println!("\\u{{2764}}\\u{{a}}\\u{{21}}");

Using to_string:

assert_eq!("โค\n!".escape_unicode().to_string(), "\\u{2764}\\u{a}\\u{21}");
pub fn substr_range(&self, substr: &str) -> Option<Range<usize>>

๐Ÿ”ฌThis is a nightly-only experimental API. (substr_range)

Returns the range that a substring points to.

Returns None if substr does not point within self.

Unlike str::find, this does not search through the string. Instead, it uses pointer arithmetic to find where in the string substr is derived from.

This is useful for extending str::split and similar methods.

Note that this method may return false positives (typically either Some(0..0) or Some(self.len()..self.len())) if substr is a zero-length str that points at the beginning or end of another, independent, str.

Examples
#![feature(substr_range)]
use core::range::Range;

let data = "a, b, b, a";
let mut iter = data.split(", ").map(|s| data.substr_range(s).unwrap());

assert_eq!(iter.next(), Some(Range { start: 0, end: 1 }));
assert_eq!(iter.next(), Some(Range { start: 3, end: 4 }));
assert_eq!(iter.next(), Some(Range { start: 6, end: 7 }));
assert_eq!(iter.next(), Some(Range { start: 9, end: 10 }));
pub fn as_str(&self) -> &str

๐Ÿ”ฌThis is a nightly-only experimental API. (str_as_str)

Returns the same string as a string slice &str.

This method is redundant when used directly on &str, but it helps dereferencing other string-like types to string slices, for example references to Box<str> or Arc<str>.

1.0.0 ยท Source

pub fn replace<P>(&self, from: P, to: &str) -> String
where P: Pattern,

Replaces all matches of a pattern with another string.

replace creates a new String, and copies the data from this string slice into it. While doing so, it attempts to find matches of a pattern. If it finds any, it replaces them with the replacement string slice.

Examples
let s = "this is old";

assert_eq!("this is new", s.replace("old", "new"));
assert_eq!("than an old", s.replace("is", "an"));

When the pattern doesnโ€™t match, it returns this string slice as String:

let s = "this is old";
assert_eq!(s, s.replace("cookie monster", "little lamb"));
1.16.0 ยท Source

pub fn replacen<P>(&self, pat: P, to: &str, count: usize) -> String
where P: Pattern,

Replaces first N matches of a pattern with another string.

replacen creates a new String, and copies the data from this string slice into it. While doing so, it attempts to find matches of a pattern. If it finds any, it replaces them with the replacement string slice at most count times.

Examples
let s = "foo foo 123 foo";
assert_eq!("new new 123 foo", s.replacen("foo", "new", 2));
assert_eq!("faa fao 123 foo", s.replacen('o', "a", 3));
assert_eq!("foo foo new23 foo", s.replacen(char::is_numeric, "new", 1));

When the pattern doesnโ€™t match, it returns this string slice as String:

let s = "this is old";
assert_eq!(s, s.replacen("cookie monster", "little lamb", 10));
1.2.0 ยท Source

pub fn to_lowercase(&self) -> String

Returns the lowercase equivalent of this string slice, as a new String.

โ€˜Lowercaseโ€™ is defined according to the terms of Chapter 3 (Conformance) of the Unicode standard.

Since some characters can expand into multiple characters when changing the case, this function returns a String instead of modifying the parameter in-place.

Unlike char::to_lowercase(), this method fully handles the context-dependent casing of Greek sigma. However, like that method, it does not handle locale-specific casing, like Turkish and Azeri I/ฤฑ/ฤฐ/i. See its documentation for more information.

Examples

Basic usage:

let s = "HELLO WORLD";

assert_eq!("hello world", s.to_lowercase());

Tricky examples, with sigma:

let sigma = "ฮฃ";

assert_eq!("ฯƒ", sigma.to_lowercase());

// but at the end of a word, it's ฯ‚, not ฯƒ:
let odysseus = "แฝˆฮ”ฮฅฮฃฮฃฮ•ฮŽฮฃ";

assert_eq!("แฝ€ฮดฯ…ฯƒฯƒฮตฯฯ‚", odysseus.to_lowercase());

let odysseus_king_of_ithaca = "ฮŸ ฮŸฮ”ฮฅฮฃฮฃฮˆฮ‘ฮฃ ฮ’ฮ‘ฮฃฮ™ฮ›ฮ™ฮ†ฮฃ ฮคฮ—ฮฃ ฮ™ฮ˜ฮ†ฮšฮ—ฮฃ";

assert_eq!("ฮฟ ฮฟฮดฯ…ฯƒฯƒฮญฮฑฯ‚ ฮฒฮฑฯƒฮนฮปฮนฮฌฯ‚ ฯ„ฮทฯ‚ ฮนฮธฮฌฮบฮทฯ‚", odysseus_king_of_ithaca.to_lowercase());

Languages without case are not changed:

let new_year = "ๅ†œๅކๆ–ฐๅนด";

assert_eq!(new_year, new_year.to_lowercase());
pub fn word_to_titlecase(&self) -> String

๐Ÿ”ฌThis is a nightly-only experimental API. (titlecase)

Returns the titlecase equivalent of this string slice, which is assumed to represent a single word, as a new String.

Essentially, this consists of uppercasing the first cased letter (with char::to_titlecase()), and lowercasing everything that follows.

โ€˜Titlecaseโ€™ is defined according to the terms of Chapter 3 (Conformance) of the Unicode standard.

Since some characters can expand into multiple characters when changing the case, this function returns a String instead of modifying the parameter in-place.

Unlike char::to_lowercase(), this method fully handles the context-dependent casing of Greek sigma. However, like that method, it does not handle locale-specific casing, like Turkish and Azeri I/ฤฑ/ฤฐ/i. See its documentation for more information.

This method does not perform any kind of word segmentation.

Examples

Basic usage:

#![feature(titlecase)]
let s = "HELLO WORLD";

assert_eq!("Hello world", s.word_to_titlecase());

The first cased letter is uppercased:

#![feature(titlecase)]
let the_night_before_christmas = "'twas";

assert_eq!("'Twas", the_night_before_christmas.word_to_titlecase());

Languages without case are not changed:

#![feature(titlecase)]
let new_year = "ๅ†œๅކๆ–ฐๅนด";

assert_eq!(new_year, new_year.word_to_titlecase());

Georgian uppercase (โ€œMtavruliโ€) letters are not used in titlecase:

#![feature(titlecase)]
let georgian = "แƒ”แƒ แƒ—แƒแƒ‘แƒแƒจแƒ˜แƒ";

assert_eq!(georgian, georgian.word_to_titlecase());

No word segmentation is performed, so only the first cased letter in the whole string gets uppercased:

#![feature(titlecase)]
let blazingly_fast = "ferris and I";

assert_eq!("Ferris and i", blazingly_fast.word_to_titlecase());

Tricky examples, with sigma:

#![feature(titlecase)]
let odysseus = "แฝˆฮ”ฮฅฮฃฮฃฮ•ฮŽฮฃ";

assert_eq!("แฝˆฮดฯ…ฯƒฯƒฮตฯฯ‚", odysseus.word_to_titlecase());

let odysseus_king_of_ithaca = "ฮŸ ฮŸฮ”ฮฅฮฃฮฃฮˆฮ‘ฮฃ ฮ’ฮ‘ฮฃฮ™ฮ›ฮ™ฮ†ฮฃ ฮคฮ—ฮฃ ฮ™ฮ˜ฮ†ฮšฮ—ฮฃ";

assert_eq!("ฮŸ ฮฟฮดฯ…ฯƒฯƒฮญฮฑฯ‚ ฮฒฮฑฯƒฮนฮปฮนฮฌฯ‚ ฯ„ฮทฯ‚ ฮนฮธฮฌฮบฮทฯ‚", odysseus_king_of_ithaca.word_to_titlecase());
1.2.0 ยท Source

pub fn to_uppercase(&self) -> String

Returns the uppercase equivalent of this string slice, as a new String.

โ€˜Uppercaseโ€™ is defined according to the terms of Chapter 3 (Conformance) of the Unicode standard.

Since some characters can expand into multiple characters when changing the case, this function returns a String instead of modifying the parameter in-place.

Like char::to_uppercase() this method does not handle language-specific casing, like Turkish and Azeri I/ฤฑ/ฤฐ/i. See that methodโ€™s documentation for more information.

Examples

Basic usage:

let s = "hello world";

assert_eq!("HELLO WORLD", s.to_uppercase());

Scripts without case are not changed:

let new_year = "ๅ†œๅކๆ–ฐๅนด";

assert_eq!(new_year, new_year.to_uppercase());

One character can become multiple:

let s = "tschรผรŸ";

assert_eq!("TSCHรœSS", s.to_uppercase());
1.16.0 ยท Source

pub fn repeat(&self, n: usize) -> String

Creates a new String by repeating a string n times.

Panics

This function will panic if the capacity would overflow.

Examples

Basic usage:

assert_eq!("abc".repeat(4), String::from("abcabcabcabc"));

A panic upon overflow:

โ“˜
// this will panic at runtime
let huge = "0123456789abcdef".repeat(usize::MAX);
1.23.0 ยท Source

pub fn to_ascii_uppercase(&self) -> String

Returns a copy of this string where each character is mapped to its ASCII upper case equivalent.

ASCII letters โ€˜aโ€™ to โ€˜zโ€™ are mapped to โ€˜Aโ€™ to โ€˜Zโ€™, but non-ASCII letters are unchanged.

To uppercase the value in-place, use make_ascii_uppercase.

To uppercase ASCII characters in addition to non-ASCII characters, use to_uppercase.

Examples
let s = "GrรผรŸe, Jรผrgen โค";

assert_eq!("GRรผรŸE, JรผRGEN โค", s.to_ascii_uppercase());
1.23.0 ยท Source

pub fn to_ascii_lowercase(&self) -> String

Returns a copy of this string where each character is mapped to its ASCII lower case equivalent.

ASCII letters โ€˜Aโ€™ to โ€˜Zโ€™ are mapped to โ€˜aโ€™ to โ€˜zโ€™, but non-ASCII letters are unchanged.

To lowercase the value in-place, use make_ascii_lowercase.

To lowercase ASCII characters in addition to non-ASCII characters, use to_lowercase.

Examples
let s = "GrรผรŸe, Jรผrgen โค";

assert_eq!("grรผรŸe, jรผrgen โค", s.to_ascii_lowercase());