Context

Struct Context 

pub struct Context { /* private fields */ }
A map of arbitrary JSON values, for use by plugins.

Context makes use of DashMap under the hood which tries to handle concurrency by allowing concurrency across threads without requiring locking. This is great for usability but could lead to surprises when updates are highly contested.

Within the router, contention is likely to be highest within plugins which provide crate::services::SubgraphRequest or crate::services::SubgraphResponse processing. At such times, plugins should restrict themselves to the Context::get and Context::upsert functions to minimise the possibility of mis-sequenced updates.

Implementations

Source

impl Context

pub fn new() -> Self

Create a new context.

Source

impl Context

pub fn extensions(&self) -> &ExtensionsMutex

Returns extensions of the context.

You can use Extensions to pass data between plugins that is not serializable. Such data is not accessible from Rhai or co-processoers.

It is CRITICAL to avoid holding on to the mutex guard for too long, particularly across async calls. Doing so may cause performance degradation or even deadlocks.

See related clippy lint for examples: https://rust-lang.github.io/rust-clippy/master/index.html#/await_holding_lock

pub fn contains_key<K>(&self, key: K) -> bool
where K: Into<String>,

Returns true if the context contains a value for the specified key.

pub fn get<K, V>(&self, key: K) -> Result<Option<V>, BoxError>
where K: Into<String>, V: for<'de> Deserialize<'de>,

Get a value from the context using the provided key.

Semantics:

  • If the operation fails, that’s because we can’t deserialize the value.
  • If the operation succeeds, the value is an Option.
pub fn insert<K, V>(&self, key: K, value: V) -> Result<Option<V>, BoxError>
where K: Into<String>, V: for<'de> Deserialize<'de> + Serialize,

Insert a value int the context using the provided key and value.

Semantics:

  • If the operation fails, then the pair has not been inserted.
  • If the operation succeeds, the result is the old value as an Option.
pub fn insert_json_value<K>(&self, key: K, value: Value) -> Option<Value>
where K: Into<String>,

Insert a value in the context using the provided key and value.

Semantics: the result is the old value as an Option.

pub fn get_json_value<K>(&self, key: K) -> Option<Value>
where K: Into<String>,

Get a json value from the context using the provided key.

pub fn upsert<K, V>( &self, key: K, upsert: impl FnOnce(V) -> V, ) -> Result<(), BoxError>
where K: Into<String>, V: for<'de> Deserialize<'de> + Serialize + Default,

Upsert a value in the context using the provided key and resolving function.

The resolving function must yield a value to be used in the context. It is provided with the current value to use in evaluating which value to yield.

Semantics:

  • If the operation fails, then the pair has not been inserted (or a current value updated).
  • If the operation succeeds, the pair have either updated an existing value or been inserted.
pub fn iter(&self) -> impl Iterator<Item = RefMulti<'_, String, Value>> + '_

Iterate over the entries.

pub fn iter_mut( &self, ) -> impl Iterator<Item = RefMutMulti<'_, String, Value>> + '_

Iterate mutably over the entries.