Struct apollo_router::Endpoint
source · pub struct Endpoint { /* private fields */ }Expand description
A path and a handler to be exposed as a web_endpoint for plugins
Implementations
sourceimpl Endpoint
impl Endpoint
sourcepub fn new(path: String, handler: BoxService) -> Self
👎Deprecated: use from_router_service instead
pub fn new(path: String, handler: BoxService) -> Self
from_router_service insteadCreates an Endpoint given a path and a Boxed Service
sourcepub fn from_router_service(path: String, handler: BoxService) -> Self
pub fn from_router_service(path: String, handler: BoxService) -> Self
Creates an Endpoint given a path and a Boxed Service