TestHarness

Struct TestHarness 

pub struct TestHarness<'a> { /* private fields */ }
Builder for the part of an Apollo Router that handles GraphQL requests, as a tower::Service.

This allows tests, benchmarks, etc to manipulate request and response objects in memory without going over the network on the supergraph side.

On the subgraph side, this test harness never makes network requests to subgraphs unless with_subgraph_network_requests is called.

Compared to running a full RouterHttpServer, this test harness is lacking:

  • Custom endpoints from plugins
  • The health check endpoint
  • CORS (FIXME: should this include CORS?)
  • HTTP compression

Example making a single request:

use apollo_router::services::supergraph;
use apollo_router::TestHarness;
use tower::util::ServiceExt;

let config = serde_json::json!({"supergraph": { "introspection": false }});
let request = supergraph::Request::fake_builder()
    // Request building here
    .build()
    .unwrap();
let response = TestHarness::builder()
    .configuration_json(config)?
    .build_router()
    .await?
    .oneshot(request.try_into().unwrap())
    .await?
    .next_response()
    .await
    .unwrap();

Implementations

Source

impl<'a> TestHarness<'a>

pub fn builder() -> Self

Creates a new builder.

pub fn log_level(self, log_level: &'a str) -> Self

Specifies the logging level. Note that this function may not be called more than once. log_level is in RUST_LOG format.

pub fn try_log_level(self, log_level: &'a str) -> Self

Specifies the logging level. Note that this function will silently fail if called more than once. log_level is in RUST_LOG format.

pub fn schema(self, schema: &'a str) -> Self

Specifies the (static) supergraph schema definition.

Panics if called more than once.

If this isn’t called, a default “canned” schema is used. It can be found in the Router repository at apollo-router/testing_schema.graphql. In that case, subgraph responses are overridden with some “canned” data.

pub fn configuration(self, configuration: Arc<Configuration>) -> Self

Specifies the (static) router configuration.

pub fn configuration_json(self, configuration: Value) -> Result<Self, Error>

Specifies the (static) router configuration as a JSON value, such as from the serde_json::json! macro.

pub fn configuration_yaml( self, configuration: &'a str, ) -> Result<Self, ConfigurationError>

Specifies the (static) router configuration as a YAML string

pub fn license_from_allowed_features( self, allowed_features: Vec<AllowedFeature>, ) -> Self

Specifies the (static) license.

Panics if called more than once.

If this isn’t called, the default license is used.

pub fn extra_plugin<P: Plugin>(self, plugin: P) -> Self

Adds an extra, already instantiated plugin.

May be called multiple times. These extra plugins are added after plugins specified in configuration.

pub fn extra_unstable_plugin<P: PluginUnstable>(self, plugin: P) -> Self

Adds an extra, already instantiated unstable plugin.

May be called multiple times. These extra plugins are added after plugins specified in configuration.

pub fn router_hook( self, callback: impl Fn(BoxService) -> BoxService + Send + Sync + 'static, ) -> Self

Adds a callback-based hook similar to Plugin::router_service

pub fn supergraph_hook( self, callback: impl Fn(BoxService) -> BoxService + Send + Sync + 'static, ) -> Self

Adds a callback-based hook similar to Plugin::supergraph_service

pub fn execution_hook( self, callback: impl Fn(BoxService) -> BoxService + Send + Sync + 'static, ) -> Self

Adds a callback-based hook similar to Plugin::execution_service

pub fn subgraph_hook( self, callback: impl Fn(&str, BoxService) -> BoxService + Send + Sync + 'static, ) -> Self

Adds a callback-based hook similar to Plugin::subgraph_service

pub fn with_subgraph_network_requests(self) -> Self

Enables this test harness to make network requests to subgraphs.

If this is not called, all subgraph requests get an empty response by default (unless schema is also not called). This behavior can be changed by implementing Plugin::subgraph_service on a plugin given to extra_plugin.

pub async fn build_supergraph(self) -> Result<BoxCloneService, BoxError>

Builds the supergraph service

pub async fn build_router(self) -> Result<BoxCloneService, BoxError>

Builds the router service

pub async fn build_http_service(self) -> Result<HttpService, BoxError>

Build the HTTP service