#[non_exhaustive]pub struct Error {
pub message: String,
pub locations: Vec<Location>,
pub path: Option<Path>,
pub extensions: Map<ByteString, Value>,
/* private fields */
}Expand description
A GraphQL error
as may be found in the errors field of a GraphQL Response.
Converted to (or from) JSON with serde.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: StringThe error message.
locations: Vec<Location>The locations of the error in the GraphQL document of the originating request.
path: Option<Path>If this is a field error, the JSON path to that field in Response::data
extensions: Map<ByteString, Value>The optional GraphQL extensions for this error.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn extension_code(&self) -> Option<String>
pub fn extension_code(&self) -> Option<String>
Extract the error code from Error::extensions as a String if it is set.
Sourcepub fn with_apollo_id(&self, id: Uuid) -> Self
pub fn with_apollo_id(&self, id: Uuid) -> Self
Returns a duplicate of the error where self.apollo_id is now the given ID
Sourceimpl Error
impl Error
Sourcepub fn builder() -> NewErrorBuilder
pub fn builder() -> NewErrorBuilder
Returns a builder that builds a GraphQL Error from its components.
Builder methods:
-
.message(impl Into<String>)Required. SetsError::message. -
.locations(impl Into<Vec<Location>>)Optional. Sets the entireVecofError::locations, which defaults to the empty. -
.location(impl Into<Location>)Optional, may be called multiple times. Adds one item at the end ofError::locations. -
.path(impl Into<Path>)Optional. SetsError::path. -
.extensions(impl Into<serde_json_bytes::Map<ByteString,Value>>)Optional. Sets the entireError::extensionsmap, which defaults to empty. -
.extension(impl Into<ByteString>, impl Into<Value>)Optional, may be called multiple times. Adds one item to theError::extensionsmap. -
.extension_code(impl Into<String>)Optional. Sets the “code” in the extension map. Will be ignored if extension already has this key set. -
.apollo_id(impl Into<Uuid>)Optional. Sets the unique identifier for this Error. This should only be used in cases of deserialization or testing. If not given, the ID will be auto-generated. -
.build()Finishes the builder and returns a GraphQLError.