pub struct UnconstrainedBufferLayer<Request> { /* private fields */ }Expand description
Adds a coop unconstrained Buffer layer to a service.
See the module documentation for more details.
Implementations
Sourceimpl<Request> UnconstrainedBufferLayer<Request>
impl<Request> UnconstrainedBufferLayer<Request>
Sourcepub const fn new(bound: usize) -> Self
pub const fn new(bound: usize) -> Self
Creates a new UnconstrainedBufferLayer with the provided bound.
bound gives the maximal number of requests that can be queued for the service before
backpressure is applied to callers.
See Buffer::new for guidance on choosing a bound.