Struct apollo_router::services::execution::Request
source ยท #[non_exhaustive]pub struct Request {
pub supergraph_request: Request<Request>,
pub query_plan: Arc<QueryPlan>,
pub context: Context,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.supergraph_request: Request<Request>Original request to the Router.
query_plan: Arc<QueryPlan>context: ContextImplementations
sourceimpl Request
impl Request
sourcepub fn builder() -> NewRequestBuilder
pub fn builder() -> NewRequestBuilder
This is the constructor (or builder) to use when constructing a real ExecutionRequest.
The parameters are not optional, because in a live situation all of these properties must be set and be correct to create a ExecutionRequest.
sourceimpl Request
impl Request
sourcepub fn fake_builder() -> FakeNewRequestBuilder
pub fn fake_builder() -> FakeNewRequestBuilder
This is the constructor (or builder) to use when constructing a โfakeโ ExecutionRequest.
This does not enforce the provision of the data that is required for a fully functional ExecutionRequest. Itโs usually enough for testing, when a fully consructed ExecutionRequest is difficult to construct and not required for the pusposes of the test.