#[non_exhaustive]pub struct Request {
pub supergraph_request: Request<Request>,
pub context: Context,
}Expand description
Represents the router processing step of the processing pipeline.
This consists of the parsed graphql Request, HTTP headers and contextual data for extensions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.supergraph_request: Request<Request>Original request to the Router.
context: ContextContext for extension
Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> NewRequestBuilder
pub fn builder() -> NewRequestBuilder
This is the constructor (or builder) to use when constructing a real Request.
Required parameters are required in non-testing code to create a Request.
Sourceimpl Request
impl Request
Sourcepub fn fake_builder() -> FakeNewRequestBuilder
pub fn fake_builder() -> FakeNewRequestBuilder
This is the constructor (or builder) to use when constructing a โfakeโ Request.
This does not enforce the provision of the data that is required for a fully functional Request. Itโs usually enough for testing, when a fully constructed Request is difficult to construct and not required for the purposes of the test.
In addition, fake requests are expected to be valid, and will panic if given invalid values.
Sourceimpl Request
impl Request
Sourcepub fn canned_builder() -> CannedNewRequestBuilder
pub fn canned_builder() -> CannedNewRequestBuilder
Create a request with an example query, for tests