pub struct Context { /* private fields */ }Expand description
A map of arbitrary JSON values, for use by plugins.
Context makes use of DashMap under the hood which tries to handle concurrency
by allowing concurrency across threads without requiring locking. This is great
for usability but could lead to surprises when updates are highly contested.
Within the router, contention is likely to be highest within plugins which
provide crate::services::SubgraphRequest or
crate::services::SubgraphResponse processing. At such times,
plugins should restrict themselves to the Context::get and Context::upsert
functions to minimise the possibility of mis-sequenced updates.
Implementations
Sourceimpl Context
impl Context
Sourcepub fn extensions(&self) -> &ExtensionsMutex
pub fn extensions(&self) -> &ExtensionsMutex
Returns extensions of the context.
You can use Extensions to pass data between plugins that is not serializable. Such data is not accessible from Rhai or co-processoers.
It is CRITICAL to avoid holding on to the mutex guard for too long, particularly across async calls. Doing so may cause performance degradation or even deadlocks.
See related clippy lint for examples: https://rust-lang.github.io/rust-clippy/master/index.html#/await_holding_lock
Sourcepub fn contains_key<K>(&self, key: K) -> bool
pub fn contains_key<K>(&self, key: K) -> bool
Returns true if the context contains a value for the specified key.
Sourcepub fn get<K, V>(&self, key: K) -> Result<Option<V>, BoxError>
pub fn get<K, V>(&self, key: K) -> Result<Option<V>, BoxError>
Get a value from the context using the provided key.
Semantics:
- If the operation fails, that’s because we can’t deserialize the value.
- If the operation succeeds, the value is an
Option.
Sourcepub fn insert<K, V>(&self, key: K, value: V) -> Result<Option<V>, BoxError>
pub fn insert<K, V>(&self, key: K, value: V) -> Result<Option<V>, BoxError>
Insert a value int the context using the provided key and value.
Semantics:
- If the operation fails, then the pair has not been inserted.
- If the operation succeeds, the result is the old value as an
Option.
Sourcepub fn insert_json_value<K>(&self, key: K, value: Value) -> Option<Value>
pub fn insert_json_value<K>(&self, key: K, value: Value) -> Option<Value>
Insert a value in the context using the provided key and value.
Semantics: the result is the old value as an Option.
Sourcepub fn get_json_value<K>(&self, key: K) -> Option<Value>
pub fn get_json_value<K>(&self, key: K) -> Option<Value>
Get a json value from the context using the provided key.
Sourcepub fn upsert<K, V>(
&self,
key: K,
upsert: impl FnOnce(V) -> V,
) -> Result<(), BoxError>
pub fn upsert<K, V>( &self, key: K, upsert: impl FnOnce(V) -> V, ) -> Result<(), BoxError>
Upsert a value in the context using the provided key and resolving function.
The resolving function must yield a value to be used in the context. It is provided with the current value to use in evaluating which value to yield.
Semantics:
- If the operation fails, then the pair has not been inserted (or a current value updated).
- If the operation succeeds, the pair have either updated an existing value or been inserted.